package com.ruoyi.hezhi.mapper;

import com.ruoyi.hezhi.domain.TbDownload;

import java.util.List;
import java.util.Map;

/**
 * 在线下载Mapper接口
 *
 * @author ruoyi
 * @date 2024-10-30
 */
public interface TbDownloadMapper
{
    /**
     * 查询在线下载
     *
     * @param downloadId 在线下载主键
     * @return 在线下载
     */
    public TbDownload selectTbDownloadByDownloadId(Long downloadId);

    /**
     * 查询在线下载列表
     *
     * @param tbDownload 在线下载
     * @return 在线下载集合
     */
    public List<TbDownload> selectTbDownloadList(TbDownload tbDownload);

    /**
     * 新增在线下载
     *
     * @param tbDownload 在线下载
     * @return 结果
     */
    public int insertTbDownload(TbDownload tbDownload);

    /**
     * 修改在线下载
     *
     * @param tbDownload 在线下载
     * @return 结果
     */
    public int updateTbDownload(TbDownload tbDownload);

    /**
     * 删除在线下载
     *
     * @param downloadId 在线下载主键
     * @return 结果
     */
    public int deleteTbDownloadByDownloadId(Long downloadId);

    /**
     * 批量删除在线下载
     *
     * @param downloadIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbDownloadByDownloadIds(Long[] downloadIds);

    /**
     * 在线下载列表
     *
     * @param params 参数
     * @return 在线下载列表列表
     */
    public List<Map<String, Object>> getDownloadList(Map<String, Object> params);
}
